==> pmml-model-1.0.6-sources.jar: org/dmg/pmml/TrainingInstances.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3._2001.xmlschema.Adapter1;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}InstanceFields"/>
 *         &lt;choice>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}TableLocator"/>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}InlineTable"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *       &lt;attribute name="isTransformed" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="recordCount" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="fieldCount" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "instanceFields",
    "tableLocator",
    "inlineTable"
})
@XmlRootElement(name = "TrainingInstances")
@Schema(min = Version.PMML_4_1)
public class TrainingInstances
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "InstanceFields", required = true)
    protected InstanceFields instanceFields;
    @XmlElement(name = "TableLocator")
    protected TableLocator tableLocator;
    @XmlElement(name = "InlineTable")
    protected InlineTable inlineTable;
    @XmlAttribute(name = "isTransformed")
    protected Boolean isTransformed;
    @XmlAttribute(name = "recordCount")
    @XmlJavaTypeAdapter(Adapter1 .class)
    protected Integer recordCount;
    @XmlAttribute(name = "fieldCount")
    @XmlJavaTypeAdapter(Adapter1 .class)
    protected Integer fieldCount;

    @Deprecated
    public TrainingInstances() {
        super();
    }

    public TrainingInstances(final InstanceFields instanceFields) {
        super();
        this.instanceFields = instanceFields;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the instanceFields property.
     * 
     * @return
     *     possible object is
     *     {@link InstanceFields }
     *     
     */
    public InstanceFields getInstanceFields() {
        return instanceFields;
    }

    /**
     * Sets the value of the instanceFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link InstanceFields }
     *     
     */
    public void setInstanceFields(InstanceFields value) {
        this.instanceFields = value;
    }

    /**
     * Gets the value of the tableLocator property.
     * 
     * @return
     *     possible object is
     *     {@link TableLocator }
     *     
     */
    public TableLocator getTableLocator() {
        return tableLocator;
    }

    /**
     * Sets the value of the tableLocator property.
     * 
     * @param value
     *     allowed object is
     *     {@link TableLocator }
     *     
     */
    public void setTableLocator(TableLocator value) {
        this.tableLocator = value;
    }

    /**
     * Gets the value of the inlineTable property.
     * 
     * @return
     *     possible object is
     *     {@link InlineTable }
     *     
     */
    public InlineTable getInlineTable() {
        return inlineTable;
    }

    /**
     * Sets the value of the inlineTable property.
     * 
     * @param value
     *     allowed object is
     *     {@link InlineTable }
     *     
     */
    public void setInlineTable(InlineTable value) {
        this.inlineTable = value;
    }

    /**
     * Gets the value of the isTransformed property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIsTransformed() {
        if (isTransformed == null) {
            return false;
        } else {
            return isTransformed;
        }
    }

    /**
     * Sets the value of the isTransformed property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIsTransformed(Boolean value) {
        this.isTransformed = value;
    }

    /**
     * Gets the value of the recordCount property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getRecordCount() {
        return recordCount;
    }

    /**
     * Sets the value of the recordCount property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRecordCount(Integer value) {
        this.recordCount = value;
    }

    /**
     * Gets the value of the fieldCount property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getFieldCount() {
        return fieldCount;
    }

    /**
     * Sets the value of the fieldCount property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFieldCount(Integer value) {
        this.fieldCount = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof TrainingInstances)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final TrainingInstances that = ((TrainingInstances) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            InstanceFields lhsInstanceFields;
            lhsInstanceFields = this.getInstanceFields();
            InstanceFields rhsInstanceFields;
            rhsInstanceFields = that.getInstanceFields();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "instanceFields", lhsInstanceFields), LocatorUtils.property(thatLocator, "instanceFields", rhsInstanceFields), lhsInstanceFields, rhsInstanceFields)) {
                return false;
            }
        }
        {
            TableLocator lhsTableLocator;
            lhsTableLocator = this.getTableLocator();
            TableLocator rhsTableLocator;
            rhsTableLocator = that.getTableLocator();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "tableLocator", lhsTableLocator), LocatorUtils.property(thatLocator, "tableLocator", rhsTableLocator), lhsTableLocator, rhsTableLocator)) {
                return false;
            }
        }
        {
            InlineTable lhsInlineTable;
            lhsInlineTable = this.getInlineTable();
            InlineTable rhsInlineTable;
            rhsInlineTable = that.getInlineTable();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "inlineTable", lhsInlineTable), LocatorUtils.property(thatLocator, "inlineTable", rhsInlineTable), lhsInlineTable, rhsInlineTable)) {
                return false;
            }
        }
        {
            boolean lhsIsTransformed;
            lhsIsTransformed = ((this.isTransformed!= null)?this.isIsTransformed():false);
            boolean rhsIsTransformed;
            rhsIsTransformed = ((that.isTransformed!= null)?that.isIsTransformed():false);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "isTransformed", lhsIsTransformed), LocatorUtils.property(thatLocator, "isTransformed", rhsIsTransformed), lhsIsTransformed, rhsIsTransformed)) {
                return false;
            }
        }
        {
            Integer lhsRecordCount;
            lhsRecordCount = this.getRecordCount();
            Integer rhsRecordCount;
            rhsRecordCount = that.getRecordCount();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "recordCount", lhsRecordCount), LocatorUtils.property(thatLocator, "recordCount", rhsRecordCount), lhsRecordCount, rhsRecordCount)) {
                return false;
            }
        }
        {
            Integer lhsFieldCount;
            lhsFieldCount = this.getFieldCount();
            Integer rhsFieldCount;
            rhsFieldCount = that.getFieldCount();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "fieldCount", lhsFieldCount), LocatorUtils.property(thatLocator, "fieldCount", rhsFieldCount), lhsFieldCount, rhsFieldCount)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            InstanceFields theInstanceFields;
            theInstanceFields = this.getInstanceFields();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "instanceFields", theInstanceFields), currentHashCode, theInstanceFields);
        }
        {
            TableLocator theTableLocator;
            theTableLocator = this.getTableLocator();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "tableLocator", theTableLocator), currentHashCode, theTableLocator);
        }
        {
            InlineTable theInlineTable;
            theInlineTable = this.getInlineTable();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "inlineTable", theInlineTable), currentHashCode, theInlineTable);
        }
        {
            boolean theIsTransformed;
            theIsTransformed = ((this.isTransformed!= null)?this.isIsTransformed():false);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "isTransformed", theIsTransformed), currentHashCode, theIsTransformed);
        }
        {
            Integer theRecordCount;
            theRecordCount = this.getRecordCount();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "recordCount", theRecordCount), currentHashCode, theRecordCount);
        }
        {
            Integer theFieldCount;
            theFieldCount = this.getFieldCount();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "fieldCount", theFieldCount), currentHashCode, theFieldCount);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            InstanceFields theInstanceFields;
            theInstanceFields = this.getInstanceFields();
            strategy.appendField(locator, this, "instanceFields", buffer, theInstanceFields);
        }
        {
            TableLocator theTableLocator;
            theTableLocator = this.getTableLocator();
            strategy.appendField(locator, this, "tableLocator", buffer, theTableLocator);
        }
        {
            InlineTable theInlineTable;
            theInlineTable = this.getInlineTable();
            strategy.appendField(locator, this, "inlineTable", buffer, theInlineTable);
        }
        {
            boolean theIsTransformed;
            theIsTransformed = ((this.isTransformed!= null)?this.isIsTransformed():false);
            strategy.appendField(locator, this, "isTransformed", buffer, theIsTransformed);
        }
        {
            Integer theRecordCount;
            theRecordCount = this.getRecordCount();
            strategy.appendField(locator, this, "recordCount", buffer, theRecordCount);
        }
        {
            Integer theFieldCount;
            theFieldCount = this.getFieldCount();
            strategy.appendField(locator, this, "fieldCount", buffer, theFieldCount);
        }
        return buffer;
    }

}

==> pmml-model-1.0.8-sources.jar: org/dmg/pmml/TrainingInstances.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3._2001.xmlschema.Adapter1;
import org.xml.sax.Locator;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}InstanceFields"/>
 *         &lt;choice>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}TableLocator"/>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}InlineTable"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *       &lt;attribute name="isTransformed" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="recordCount" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="fieldCount" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "instanceFields",
    "tableLocator",
    "inlineTable"
})
@XmlRootElement(name = "TrainingInstances")
@Schema(min = Version.PMML_4_1)
public class TrainingInstances
    extends PMMLObject
    implements Locatable, Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "InstanceFields", required = true)
    protected InstanceFields instanceFields;
    @XmlElement(name = "TableLocator")
    protected TableLocator tableLocator;
    @XmlElement(name = "InlineTable")
    protected InlineTable inlineTable;
    @XmlAttribute(name = "isTransformed")
    protected Boolean isTransformed;
    @XmlAttribute(name = "recordCount")
    @XmlJavaTypeAdapter(Adapter1 .class)
    protected Integer recordCount;
    @XmlAttribute(name = "fieldCount")
    @XmlJavaTypeAdapter(Adapter1 .class)
    protected Integer fieldCount;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    @Deprecated
    public TrainingInstances() {
        super();
    }

    public TrainingInstances(final InstanceFields instanceFields) {
        super();
        this.instanceFields = instanceFields;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the instanceFields property.
     * 
     * @return
     *     possible object is
     *     {@link InstanceFields }
     *     
     */
    public InstanceFields getInstanceFields() {
        return instanceFields;
    }

    /**
     * Sets the value of the instanceFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link InstanceFields }
     *     
     */
    public void setInstanceFields(InstanceFields value) {
        this.instanceFields = value;
    }

    /**
     * Gets the value of the tableLocator property.
     * 
     * @return
     *     possible object is
     *     {@link TableLocator }
     *     
     */
    public TableLocator getTableLocator() {
        return tableLocator;
    }

    /**
     * Sets the value of the tableLocator property.
     * 
     * @param value
     *     allowed object is
     *     {@link TableLocator }
     *     
     */
    public void setTableLocator(TableLocator value) {
        this.tableLocator = value;
    }

    /**
     * Gets the value of the inlineTable property.
     * 
     * @return
     *     possible object is
     *     {@link InlineTable }
     *     
     */
    public InlineTable getInlineTable() {
        return inlineTable;
    }

    /**
     * Sets the value of the inlineTable property.
     * 
     * @param value
     *     allowed object is
     *     {@link InlineTable }
     *     
     */
    public void setInlineTable(InlineTable value) {
        this.inlineTable = value;
    }

    /**
     * Gets the value of the isTransformed property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIsTransformed() {
        if (isTransformed == null) {
            return false;
        } else {
            return isTransformed;
        }
    }

    /**
     * Sets the value of the isTransformed property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIsTransformed(Boolean value) {
        this.isTransformed = value;
    }

    /**
     * Gets the value of the recordCount property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getRecordCount() {
        return recordCount;
    }

    /**
     * Sets the value of the recordCount property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRecordCount(Integer value) {
        this.recordCount = value;
    }

    /**
     * Gets the value of the fieldCount property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getFieldCount() {
        return fieldCount;
    }

    /**
     * Sets the value of the fieldCount property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFieldCount(Integer value) {
        this.fieldCount = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof TrainingInstances)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final TrainingInstances that = ((TrainingInstances) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            InstanceFields lhsInstanceFields;
            lhsInstanceFields = this.getInstanceFields();
            InstanceFields rhsInstanceFields;
            rhsInstanceFields = that.getInstanceFields();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "instanceFields", lhsInstanceFields), LocatorUtils.property(thatLocator, "instanceFields", rhsInstanceFields), lhsInstanceFields, rhsInstanceFields)) {
                return false;
            }
        }
        {
            TableLocator lhsTableLocator;
            lhsTableLocator = this.getTableLocator();
            TableLocator rhsTableLocator;
            rhsTableLocator = that.getTableLocator();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "tableLocator", lhsTableLocator), LocatorUtils.property(thatLocator, "tableLocator", rhsTableLocator), lhsTableLocator, rhsTableLocator)) {
                return false;
            }
        }
        {
            InlineTable lhsInlineTable;
            lhsInlineTable = this.getInlineTable();
            InlineTable rhsInlineTable;
            rhsInlineTable = that.getInlineTable();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "inlineTable", lhsInlineTable), LocatorUtils.property(thatLocator, "inlineTable", rhsInlineTable), lhsInlineTable, rhsInlineTable)) {
                return false;
            }
        }
        {
            boolean lhsIsTransformed;
            lhsIsTransformed = ((this.isTransformed!= null)?this.isIsTransformed():false);
            boolean rhsIsTransformed;
            rhsIsTransformed = ((that.isTransformed!= null)?that.isIsTransformed():false);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "isTransformed", lhsIsTransformed), LocatorUtils.property(thatLocator, "isTransformed", rhsIsTransformed), lhsIsTransformed, rhsIsTransformed)) {
                return false;
            }
        }
        {
            Integer lhsRecordCount;
            lhsRecordCount = this.getRecordCount();
            Integer rhsRecordCount;
            rhsRecordCount = that.getRecordCount();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "recordCount", lhsRecordCount), LocatorUtils.property(thatLocator, "recordCount", rhsRecordCount), lhsRecordCount, rhsRecordCount)) {
                return false;
            }
        }
        {
            Integer lhsFieldCount;
            lhsFieldCount = this.getFieldCount();
            Integer rhsFieldCount;
            rhsFieldCount = that.getFieldCount();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "fieldCount", lhsFieldCount), LocatorUtils.property(thatLocator, "fieldCount", rhsFieldCount), lhsFieldCount, rhsFieldCount)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            InstanceFields theInstanceFields;
            theInstanceFields = this.getInstanceFields();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "instanceFields", theInstanceFields), currentHashCode, theInstanceFields);
        }
        {
            TableLocator theTableLocator;
            theTableLocator = this.getTableLocator();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "tableLocator", theTableLocator), currentHashCode, theTableLocator);
        }
        {
            InlineTable theInlineTable;
            theInlineTable = this.getInlineTable();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "inlineTable", theInlineTable), currentHashCode, theInlineTable);
        }
        {
            boolean theIsTransformed;
            theIsTransformed = ((this.isTransformed!= null)?this.isIsTransformed():false);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "isTransformed", theIsTransformed), currentHashCode, theIsTransformed);
        }
        {
            Integer theRecordCount;
            theRecordCount = this.getRecordCount();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "recordCount", theRecordCount), currentHashCode, theRecordCount);
        }
        {
            Integer theFieldCount;
            theFieldCount = this.getFieldCount();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "fieldCount", theFieldCount), currentHashCode, theFieldCount);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            InstanceFields theInstanceFields;
            theInstanceFields = this.getInstanceFields();
            strategy.appendField(locator, this, "instanceFields", buffer, theInstanceFields);
        }
        {
            TableLocator theTableLocator;
            theTableLocator = this.getTableLocator();
            strategy.appendField(locator, this, "tableLocator", buffer, theTableLocator);
        }
        {
            InlineTable theInlineTable;
            theInlineTable = this.getInlineTable();
            strategy.appendField(locator, this, "inlineTable", buffer, theInlineTable);
        }
        {
            boolean theIsTransformed;
            theIsTransformed = ((this.isTransformed!= null)?this.isIsTransformed():false);
            strategy.appendField(locator, this, "isTransformed", buffer, theIsTransformed);
        }
        {
            Integer theRecordCount;
            theRecordCount = this.getRecordCount();
            strategy.appendField(locator, this, "recordCount", buffer, theRecordCount);
        }
        {
            Integer theFieldCount;
            theFieldCount = this.getFieldCount();
            strategy.appendField(locator, this, "fieldCount", buffer, theFieldCount);
        }
        return buffer;
    }

}
